## 深证互动易

接口：irm_qa_sz，历史数据开始于2010年10月。

描述：互动易是由深交所官方推出,供投资者与上市公司直接沟通的平台,一站式公司资讯汇集,提供第一手的互动问答、投资者关系信息、公司声音等内容。

限量：单次请求最大返回3000行数据，可根据股票代码，日期等参数循环提取全部数据

权限：用户后120积分可以试用，正式权限为10000积分，或申请单独开权限，请参考权限说明

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| trade_date | str | N | 交易日期（格式YYYYMMDD，下同） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| pub_date | str | N | 发布开始日期(格式：2025-06-03 16:43:03) |
| pub_date | str | N | 发布结束日期(格式：2025-06-03 18:43:23) |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| name | str | Y | 公司名称 |
| trade_date | str | Y | 发布时间 |
| q | str | Y | 问题 |
| a | str | Y | 回复 |
| pub_time | str | Y | 答复时间 |
| industry | str | Y | 涉及行业 |

接口调用

```python
pro = ts.pro_api()

#获取2025年2月12日深证互动易的问答文本
df = pro.irm_qa_sz(ann_date='20250212')
```

数据样例

```python
ts_code  name   trade_date                                                  q                                                  a             pub_time         industry
0   002254  泰和新材   20250212    请问宋总公司有无F12芳纶的研究成果，有无选择一家很有发展前途的公司并购重组，把公司做大做强。            您好，非常感谢您对公司的关注。公司正研发类似产品，以丰富公司的产品品类。谢谢！  2025-02-12 21:46:32              制造业
```